@@ -1,7 +1,6 @@
 module Language.Haskell.HsColour.Options
   ( Option(..)
   , Output(..)
-  , Literate(..)
   ) where 
 
 import Language.Haskell.HsColour.Output
@@ -12,11 +11,9 @@ data Option =
   | Version		-- ^ report version
   | Information		-- ^ report auxiliary information, e.g. CSS defaults
   | Format Output	-- ^ what type of output to produce
-  | LHS Literate	-- ^ literate input (i.e. multiple embedded fragments)
+  | LHS Bool		-- ^ literate input (i.e. multiple embedded fragments)
   | Anchors Bool	-- ^ whether to add anchors
   | Partial Bool	-- ^ whether to produce a full document or partial
   | Input FilePath	-- ^ input source file
   | Output FilePath	-- ^ output source file
   deriving Eq
-
-data Literate = NoLit | Bird | TeX deriving Eq
